@@ -1,11 +1,9 @@
 # -*- coding: utf-8 -*-
 """
-MIT License
-===========
+Spyder License Agreement (MIT License)
+--------------------------------------
 
-The spyder/images dir and some source files under other terms (see NOTICE.txt).
-
-Copyright (c) 2009- Spyder Project Contributors and others (see AUTHORS.txt)
+Copyright (c) Spyder Project Contributors
 
 Permission is hereby granted, free of charge, to any person
 obtaining a copy of this software and associated documentation
@@ -29,15 +27,12 @@ FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 OTHER DEALINGS IN THE SOFTWARE.
 """
 
-version_info = (3, 3, 4)
+version_info = (3, 1, 3)
 
 __version__ = '.'.join(map(str, version_info))
 __license__ = __doc__
 __project_url__ = 'https://github.com/spyder-ide/spyder'
-__forum_url__   = 'https://groups.google.com/group/spyderlib'
-__trouble_url__ = __project_url__ + '/wiki/Troubleshooting-Guide-and-FAQ'
-__trouble_url_short__ = 'https://tinyurl.com/SpyderHelp'
-__website_url__ = 'https://www.spyder-ide.org/'
+__forum_url__   = 'http://groups.google.com/group/spyderlib'
 
 # Dear (Debian, RPM, ...) package makers, please feel free to customize the
 # following path to module's data (images) and translations:
@@ -87,9 +82,8 @@ def get_versions(reporev=True):
         'python': platform.python_version(),  # "2.7.3"
         'bitness': 64 if sys.maxsize > 2**32 else 32,
         'qt': qtpy.QtCore.__version__,
-        'qt_api': qtpy.API_NAME,      # PyQt5
+        'qt_api': qtpy.API_NAME,      # PyQt5 or PyQt4
         'qt_api_ver': qtpy.PYQT_VERSION,
         'system': system,   # Linux, Windows, ...
-        'release': platform.release(),  # XP, 10.6, 2.2.0, etc.
         'revision': revision,  # '9fdf926eccce'
     }
