@@ -48,10 +48,7 @@ class DefaultsConfig(cp.ConfigParser):
     UserConfig
     """
     def __init__(self, name, subfolder):
-        if PY2:
-            cp.ConfigParser.__init__(self)
-        else:
-            cp.ConfigParser.__init__(self, interpolation=None)
+        cp.ConfigParser.__init__(self)
         self.name = name
         self.subfolder = subfolder
 
@@ -85,7 +82,7 @@ class DefaultsConfig(cp.ConfigParser):
         if not is_text_string(value):
             value = repr( value )
         if verbose:
-            print('%s[ %s ] = %s' % (section, option, value))  # spyder: test-skip
+            print('%s[ %s ] = %s' % (section, option, value))
         cp.ConfigParser.set(self, section, option, value)
 
     def _save(self):
@@ -119,8 +116,8 @@ class DefaultsConfig(cp.ConfigParser):
                 time.sleep(0.05)
                 _write_file(fname)
             except Exception as e:
-                print("Failed to write user configuration file.")  # spyder: test-skip
-                print("Please submit a bug report.")  # spyder: test-skip
+                print("Failed to write user configuration file.")
+                print("Please submit a bug report.")
                 raise(e)
 
     def filename(self):
@@ -187,8 +184,7 @@ class UserConfig(DefaultsConfig):
                  remove_obsolete=False):
         DefaultsConfig.__init__(self, name, subfolder)
         self.raw = 1 if raw_mode else 0
-        if (version is not None and
-                re.match(r'^(\d+).(\d+).(\d+)$', version) is None):
+        if (version is not None) and (re.match('^(\d+).(\d+).(\d+)$', version) is None):
             raise ValueError("Version number %r is incorrect - must be in X.Y.Z format" % version)
         if isinstance(defaults, dict):
             defaults = [ (self.DEFAULT_SECTION_NAME, defaults) ]
@@ -250,12 +246,12 @@ class UserConfig(DefaultsConfig):
                         with codecs.open(fname, encoding='utf-8') as configfile:
                             self.readfp(configfile)
                     except IOError:
-                        print("Failed reading file", fname)  # spyder: test-skip
+                        print("Failed reading file", fname)
             else:
                 # Python 3
                 self.read(self.filename(), encoding='utf-8')
         except cp.MissingSectionHeaderError:
-            print("Warning: File contains no section headers.")  # spyder: test-skip
+            print("Warning: File contains no section headers.")
     
     def _load_old_defaults(self, old_version):
         """Read old defaults"""
@@ -390,20 +386,12 @@ class UserConfig(DefaultsConfig):
             value = float(value)
         elif isinstance(default_value, int):
             value = int(value)
-        elif is_text_string(default_value):
-            if PY2:
+        else:
+            if PY2 and is_text_string(default_value):
                 try:
                     value = value.decode('utf-8')
-                    try:
-                        # Some str config values expect to be eval after decoding
-                        new_value = ast.literal_eval(value)
-                        if is_text_string(new_value):
-                            value = new_value
-                    except (SyntaxError, ValueError):
-                        pass
                 except (UnicodeEncodeError, UnicodeDecodeError):
                     pass
-        else:
             try:
                 # lists, tuples, ...
                 value = ast.literal_eval(value)
