@@ -12,8 +12,7 @@ import os.path as osp
 import sys
 import stat
 
-from spyder.py3compat import is_text_string, getcwd
-from spyder.config.base import get_home_dir, debug_print
+from spyder.py3compat import is_text_string
 
 
 def __remove_pyc_pyo(fname):
@@ -125,6 +124,26 @@ def count_lines(path, extensions=None, excluded_dirnames=None):
     return files, lines
 
 
+def fix_reference_name(name, blacklist=None):
+    """Return a syntax-valid Python reference name from an arbitrary name"""
+    import re
+    name = "".join(re.split(r'[^0-9a-zA-Z_]', name))
+    while name and not re.match(r'([a-zA-Z]+[0-9a-zA-Z_]*)$', name):
+        if not re.match(r'[a-zA-Z]', name[0]):
+            name = name[1:]
+            continue
+    name = str(name)
+    if not name:
+        name = "data"
+    if blacklist is not None and name in blacklist:
+        get_new_name = lambda index: name+('%03d' % index)
+        index = 0
+        while get_new_name(index) in blacklist:
+            index += 1
+        name = get_new_name(index)
+    return name
+
+
 def remove_backslashes(path):
     """Remove backslashes in *path*
 
@@ -179,7 +198,7 @@ def monkeypatch_method(cls, patch_name):
         if old_func is not None:
             # Add the old func to a list of old funcs.
             old_ref = "_old_%s_%s" % (patch_name, fname)
-
+            #print old_ref, old_func
             old_attr = getattr(cls, old_ref, None)
             if old_attr is None:
                 setattr(cls, old_ref, old_func)
@@ -266,15 +285,18 @@ def memoize(obj):
     return memoizer
 
 
-def getcwd_or_home():
-    """Safe version of getcwd that will fallback to home user dir.
-
-    This will catch the error raised when the current working directory
-    was removed for an external program.
-    """
-    try:
-        return getcwd()
-    except OSError:
-        debug_print("WARNING: Current working directory was deleted, "
-                    "falling back to home dirertory")
-        return get_home_dir()
+if __name__ == '__main__':
+    if os.name == 'nt':
+        assert get_common_path([
+                                'D:\\Python\\spyder-v21\\spyder\\widgets',
+                                'D:\\Python\\spyder\\spyder\\utils',
+                                'D:\\Python\\spyder\\spyder\\widgets',
+                                'D:\\Python\\spyder-v21\\spyder\\utils',
+                                ]) == 'D:\\Python'
+    else:
+        assert get_common_path([
+                                '/Python/spyder-v21/spyder.widgets',
+                                '/Python/spyder/spyder.utils',
+                                '/Python/spyder/spyder.widgets',
+                                '/Python/spyder-v21/spyder.utils',
+                                ]) == '/Python'
