@@ -21,28 +21,23 @@ from threading import Thread
 import time
 
 # Third party imports (qtpy)
-from qtpy.QtCore import QUrl, QTimer, Signal, Slot
+from qtpy.QtCore import Qt, QUrl, Signal, Slot
 from qtpy.QtGui import QKeySequence
-from qtpy.QtWidgets import (QHBoxLayout, QLabel, QMenu, QMessageBox,
-                            QToolButton, QVBoxLayout, QWidget)
+from qtpy.QtWidgets import (QHBoxLayout, QMenu, QMessageBox, QToolButton,
+                            QVBoxLayout, QWidget)
 
 # Local imports
-from spyder.config.base import (_, get_image_path, get_module_source_path,
-                                running_under_pytest)
+from spyder.config.base import (_, get_conf_path, get_image_path,
+                                get_module_source_path)
 from spyder.config.gui import get_font, get_shortcut
 from spyder.utils import icon_manager as ima
 from spyder.utils import sourcecode
-from spyder.utils.encoding import get_coding
-from spyder.utils.environ import RemoteEnvDialog
 from spyder.utils.programs import TEMPDIR
 from spyder.utils.qthelpers import (add_actions, create_action,
-                                    create_toolbutton, DialogManager,
-                                    MENU_SEPARATOR)
-from spyder.py3compat import to_text_string
+                                    create_toolbutton)
 from spyder.widgets.browser import WebView
-from spyder.widgets.ipythonconsole import ShellWidget
 from spyder.widgets.mixins import SaveHistoryMixin
-from spyder.widgets.variableexplorer.collectionseditor import CollectionsEditor
+from spyder.widgets.ipythonconsole import ShellWidget
 
 
 #-----------------------------------------------------------------------------
@@ -58,11 +53,6 @@ BLANK = open(osp.join(TEMPLATES_PATH, 'blank.html')).read()
 LOADING = open(osp.join(TEMPLATES_PATH, 'loading.html')).read()
 KERNEL_ERROR = open(osp.join(TEMPLATES_PATH, 'kernel_error.html')).read()
 
-try:
-    time.monotonic  # time.monotonic new in 3.3
-except AttributeError:
-    time.monotonic = time.time
-
 
 #-----------------------------------------------------------------------------
 # Auxiliary functions
@@ -89,42 +79,30 @@ class ClientWidget(QWidget, SaveHistoryMixin):
     to print different messages there.
     """
 
-    SEPARATOR = '{0}## ---({1})---'.format(os.linesep*2, time.ctime())
-    INITHISTORY = ['# -*- coding: utf-8 -*-',
-                   '# *** Spyder Python Console History Log ***',]
-
+    SEPARATOR = '%s##---(%s)---' % (os.linesep*2, time.ctime())
     append_to_history = Signal(str, str)
 
-    def __init__(self, plugin, id_,
-                 history_filename, config_options,
+    def __init__(self, plugin, name, history_filename, config_options,
                  additional_options, interpreter_versions,
                  connection_file=None, hostname=None,
                  menu_actions=None, slave=False,
-                 external_kernel=False, given_name=None,
-                 show_elapsed_time=False,
-                 reset_warning=True):
+                 external_kernel=False):
         super(ClientWidget, self).__init__(plugin)
-        SaveHistoryMixin.__init__(self, history_filename)
+        SaveHistoryMixin.__init__(self)
 
         # --- Init attrs
-        self.id_ = id_
+        self.name = name
+        self.history_filename = get_conf_path(history_filename)
         self.connection_file = connection_file
         self.hostname = hostname
         self.menu_actions = menu_actions
         self.slave = slave
-        self.external_kernel = external_kernel
-        self.given_name = given_name
-        self.show_elapsed_time = show_elapsed_time
-        self.reset_warning = reset_warning
 
         # --- Other attrs
         self.options_button = None
         self.stop_button = None
-        self.reset_button = None
         self.stop_icon = ima.icon('stop')
         self.history = []
-        self.allow_rename = True
-        self.stderr_dir = None
 
         # --- Widgets
         self.shellwidget = ShellWidget(config=config_options,
@@ -138,21 +116,12 @@ class ClientWidget(QWidget, SaveHistoryMixin):
         self.loading_page = self._create_loading_page()
         self._show_loading_page()
 
-        # Elapsed time
-        self.time_label = None
-        self.t0 = None
-        self.timer = QTimer(self)
-
         # --- Layout
         vlayout = QVBoxLayout()
         toolbar_buttons = self.get_toolbar_buttons()
-
         hlayout = QHBoxLayout()
-        hlayout.addWidget(self.create_time_label())
-        hlayout.addStretch(0)
         for button in toolbar_buttons:
             hlayout.addWidget(button)
-
         vlayout.addLayout(hlayout)
         vlayout.setContentsMargins(0, 0, 0, 0)
         vlayout.addWidget(self.shellwidget)
@@ -162,35 +131,19 @@ class ClientWidget(QWidget, SaveHistoryMixin):
         # --- Exit function
         self.exit_callback = lambda: plugin.close_client(client=self)
 
-        # --- Dialog manager
-        self.dialog_manager = DialogManager()
-
-        # Show timer
-        self.update_time_label_visibility()
+        # --- Signals
+        # As soon as some content is printed in the console, stop
+        # our loading animation
+        document = self.get_control().document()
+        document.contentsChange.connect(self._hide_loading_page)
 
     #------ Public API --------------------------------------------------------
-    @property
-    def kernel_id(self):
-        """Get kernel id"""
-        if self.connection_file is not None:
-            json_file = osp.basename(self.connection_file)
-            return json_file.split('.json')[0]
-
     @property
     def stderr_file(self):
         """Filename to save kernel stderr output."""
-        stderr_file = None
-        if self.connection_file is not None:
-            stderr_file = self.kernel_id + '.stderr'
-            if self.stderr_dir is not None:
-                stderr_file = osp.join(self.stderr_dir, stderr_file)
-            else:
-                try:
-                    if not osp.isdir(TEMPDIR):
-                        os.makedirs(TEMPDIR)
-                    stderr_file = osp.join(TEMPDIR, stderr_file)
-                except (IOError, OSError):
-                    stderr_file = None
+        json_file = osp.basename(self.connection_file)
+        stderr_file = json_file.split('json')[0] + 'stderr'
+        stderr_file = osp.join(TEMPDIR, stderr_file)
         return stderr_file
 
     def configure_shellwidget(self, give_focus=True):
@@ -205,8 +158,7 @@ class ClientWidget(QWidget, SaveHistoryMixin):
         self.shellwidget.executing.connect(self.add_to_history)
 
         # For Mayavi to run correctly
-        self.shellwidget.executing.connect(
-            self.shellwidget.set_backend_for_mayavi)
+        self.shellwidget.executing.connect(self.set_backend_for_mayavi)
 
         # To update history after execution
         self.shellwidget.executed.connect(self.update_history)
@@ -225,27 +177,6 @@ class ClientWidget(QWidget, SaveHistoryMixin):
         self.shellwidget.sig_kernel_restarted.connect(
             self.kernel_restarted_message)
 
-        # To correctly change Matplotlib backend interactively
-        self.shellwidget.executing.connect(
-            self.shellwidget.change_mpl_backend)
-
-        # To show env and sys.path contents
-        self.shellwidget.sig_show_syspath.connect(self.show_syspath)
-        self.shellwidget.sig_show_env.connect(self.show_env)
-
-        # To sync with working directory toolbar
-        self.shellwidget.executed.connect(self.shellwidget.get_cwd)
-
-        # To apply style
-        self.set_color_scheme(self.shellwidget.syntax_style, reset=False)
-
-        # To hide the loading page
-        self.shellwidget.sig_prompt_ready.connect(self._hide_loading_page)
-
-        # Show possible errors when setting Matplotlib backend
-        self.shellwidget.sig_prompt_ready.connect(
-            self._show_mpl_backend_errors)
-
     def enable_stop_button(self):
         self.stop_button.setEnabled(True)
 
@@ -287,18 +218,8 @@ class ClientWidget(QWidget, SaveHistoryMixin):
 
     def get_name(self):
         """Return client name"""
-        if self.given_name is None:
-            # Name according to host
-            if self.hostname is None:
-                name = _("Console")
-            else:
-                name = self.hostname
-            # Adding id to name
-            client_id = self.id_['int_id'] + u'/' + self.id_['str_id']
-            name = name + u' ' + client_id
-        else:
-            name = self.given_name + u'/' + self.id_['str_id']
-        return name
+        return ((_("Console") if self.hostname is None else self.hostname)
+                + " " + self.name)
 
     def get_control(self):
         """Return the text widget (or similar) to give focus to"""
@@ -315,43 +236,11 @@ class ClientWidget(QWidget, SaveHistoryMixin):
 
     def get_options_menu(self):
         """Return options menu"""
-        reset_action = create_action(self, _("Remove all variables"),
-                                     icon=ima.icon('editdelete'),
-                                     triggered=self.reset_namespace)
-
-        self.show_time_action = create_action(self, _("Show elapsed time"),
-                                         toggled=self.set_elapsed_time_visible)
-
-        env_action = create_action(
-                        self,
-                        _("Show environment variables"),
-                        icon=ima.icon('environ'),
-                        triggered=self.shellwidget.get_env
-                     )
-
-        syspath_action = create_action(
-                            self,
-                            _("Show sys.path contents"),
-                            icon=ima.icon('syspath'),
-                            triggered=self.shellwidget.get_syspath
-                         )
-
-        self.show_time_action.setChecked(self.show_elapsed_time)
-        additional_actions = [reset_action,
-                              MENU_SEPARATOR,
-                              env_action,
-                              syspath_action,
-                              self.show_time_action]
-
-        if self.menu_actions is not None:
-            return self.menu_actions + additional_actions
-        else:
-            return additional_actions
+        return self.menu_actions
 
     def get_toolbar_buttons(self):
         """Return toolbar buttons list."""
         buttons = []
-
         # Code to add the stop button
         if self.stop_button is None:
             self.stop_button = create_toolbutton(
@@ -365,17 +254,6 @@ class ClientWidget(QWidget, SaveHistoryMixin):
         if self.stop_button is not None:
             buttons.append(self.stop_button)
 
-        # Reset namespace button
-        if self.reset_button is None:
-            self.reset_button = create_toolbutton(
-                                    self,
-                                    text=_("Remove"),
-                                    icon=ima.icon('editdelete'),
-                                    tip=_("Remove all variables"),
-                                    triggered=self.reset_namespace)
-        if self.reset_button is not None:
-            buttons.append(self.reset_button)
-
         if self.options_button is None:
             options = self.get_options_menu()
             if options:
@@ -397,28 +275,20 @@ class ClientWidget(QWidget, SaveHistoryMixin):
                                                     'inspect current object')),
                                     icon=ima.icon('MessageBoxInformation'),
                                     triggered=self.inspect_object)
-
         clear_line_action = create_action(self, _("Clear line or block"),
-                                          QKeySequence(get_shortcut(
-                                                  'console',
-                                                  'clear line')),
+                                          QKeySequence("Shift+Escape"),
+                                          icon=ima.icon('editdelete'),
                                           triggered=self.clear_line)
-
-        reset_namespace_action = create_action(self, _("Remove all variables"),
-                                               QKeySequence(get_shortcut(
-                                                       'ipython_console',
-                                                       'reset namespace')),
-                                               icon=ima.icon('editdelete'),
-                                               triggered=self.reset_namespace)
-
+        reset_namespace_action = create_action(self, _("Reset namespace"),
+                                          QKeySequence("Ctrl+Alt+R"),
+                                          triggered=self.reset_namespace)
         clear_console_action = create_action(self, _("Clear console"),
                                              QKeySequence(get_shortcut('console',
                                                                'clear shell')),
+                                             icon=ima.icon('editclear'),
                                              triggered=self.clear_console)
-
         quit_action = create_action(self, _("&Quit"), icon=ima.icon('exit'),
                                     triggered=self.exit_callback)
-
         add_actions(menu, (None, inspect_action, clear_line_action,
                            clear_console_action, reset_namespace_action,
                            None, quit_action))
@@ -434,10 +304,6 @@ class ClientWidget(QWidget, SaveHistoryMixin):
         font = get_font(option='rich_font')
         self.infowidget.set_font(font)
 
-    def set_color_scheme(self, color_scheme, reset=True):
-        """Set IPython color scheme."""
-        self.shellwidget.set_color_scheme(color_scheme, reset)
-
     def shutdown(self):
         """Shutdown kernel"""
         if self.get_kernel() is not None and not self.slave:
@@ -447,32 +313,22 @@ class ClientWidget(QWidget, SaveHistoryMixin):
 
     def interrupt_kernel(self):
         """Interrupt the associanted Spyder kernel if it's running"""
-        # Needed to prevent a crash when a kernel is not running.
-        # See issue 6299
-        try:
-            self.shellwidget.request_interrupt_kernel()
-        except RuntimeError:
-            pass
+        self.shellwidget.request_interrupt_kernel()
 
     @Slot()
     def restart_kernel(self):
         """
-        Restart the associated kernel.
+        Restart the associanted kernel
 
         Took this code from the qtconsole project
         Licensed under the BSD license
         """
-        sw = self.shellwidget
-
-        if not running_under_pytest():
-            message = _('Are you sure you want to restart the kernel?')
-            buttons = QMessageBox.Yes | QMessageBox.No
-            result = QMessageBox.question(self, _('Restart kernel?'),
-                                          message, buttons)
-        else:
-            result = None
-
-        if result == QMessageBox.Yes or running_under_pytest():
+        message = _('Are you sure you want to restart the kernel?')
+        buttons = QMessageBox.Yes | QMessageBox.No
+        result = QMessageBox.question(self, _('Restart kernel?'),
+                                      message, buttons)
+        if result == QMessageBox.Yes:
+            sw = self.shellwidget
             if sw.kernel_manager:
                 if self.infowidget.isVisible():
                     self.infowidget.hide()
@@ -485,12 +341,10 @@ class ClientWidget(QWidget, SaveHistoryMixin):
                         before_prompt=True
                     )
                 else:
-                    # For issue 6235.  IPython was changing the setting of
-                    # %colors on windows by assuming it was using a dark
-                    # background.  This corrects it based on the scheme.
-                    self.set_color_scheme(sw.syntax_style)
+                    sw.reset(clear=True)
                     sw._append_html(_("<br>Restarting kernel...\n<hr><br>"),
-                                    before_prompt=False)
+                        before_prompt=False,
+                    )
             else:
                 sw._append_plain_text(
                     _('Cannot restart a kernel not started by Spyder\n'),
@@ -500,19 +354,7 @@ class ClientWidget(QWidget, SaveHistoryMixin):
     @Slot(str)
     def kernel_restarted_message(self, msg):
         """Show kernel restarted/died messages."""
-        try:
-            stderr = codecs.open(self.stderr_file, 'r',
-                                 encoding='utf-8').read()
-        except UnicodeDecodeError:
-            # This is needed since the stderr file could be encoded
-            # in something different to utf-8.
-            # See issue 4191
-            try:
-                stderr = self._read_stderr()
-            except:
-                stderr = None
-        except (OSError, IOError):
-            stderr = None
+        stderr = codecs.open(self.stderr_file, 'r', encoding='utf-8').read()
 
         if stderr:
             self.show_kernel_error('<tt>%s</tt>' % stderr)
@@ -539,67 +381,27 @@ class ClientWidget(QWidget, SaveHistoryMixin):
     @Slot()
     def reset_namespace(self):
         """Resets the namespace by removing all names defined by the user"""
-        self.shellwidget.reset_namespace(warning=self.reset_warning,
-                                         message=True)
+        self.shellwidget.reset_namespace()
 
     def update_history(self):
         self.history = self.shellwidget._history
 
-    @Slot(object)
-    def show_syspath(self, syspath):
-        """Show sys.path contents."""
-        if syspath is not None:
-            editor = CollectionsEditor()
-            editor.setup(syspath, title="sys.path contents", readonly=True,
-                         width=600, icon=ima.icon('syspath'))
-            self.dialog_manager.show(editor)
-        else:
-            return
-
-    @Slot(object)
-    def show_env(self, env):
-        """Show environment variables."""
-        self.dialog_manager.show(RemoteEnvDialog(env))
-
-    def create_time_label(self):
-        """Create elapsed time label widget (if necessary) and return it"""
-        if self.time_label is None:
-            self.time_label = QLabel()
-        return self.time_label
-
-    def show_time(self, end=False):
-        """Text to show in time_label."""
-        if self.time_label is None:
-            return
-
-        elapsed_time = time.monotonic() - self.t0
-        # System time changed to past date, so reset start.
-        if elapsed_time < 0:
-            self.t0 = time.monotonic()
-            elapsed_time = 0
-        if elapsed_time > 24 * 3600:  # More than a day...!
-            fmt = "%d %H:%M:%S"
-        else:
-            fmt = "%H:%M:%S"
-        if end:
-            color = "#AAAAAA"
-        else:
-            color = "#AA6655"
-        text = "<span style=\'color: %s\'><b>%s" \
-               "</b></span>" % (color,
-                                time.strftime(fmt, time.gmtime(elapsed_time)))
-        self.time_label.setText(text)
-
-    def update_time_label_visibility(self):
-        """Update elapsed time visibility."""
-        self.time_label.setVisible(self.show_elapsed_time)
-
-    @Slot(bool)
-    def set_elapsed_time_visible(self, state):
-        """Slot to show/hide elapsed time label."""
-        self.show_elapsed_time = state
-        if self.time_label is not None:
-            self.time_label.setVisible(state)
+    def set_backend_for_mayavi(self, command):
+        """
+        Mayavi plots require the Qt backend, so we try to detect if one is
+        generated to change backends
+        """
+        calling_mayavi = False
+        lines = command.splitlines()
+        for l in lines:
+            if not l.startswith('#'):
+                if 'import mayavi' in l or 'from mayavi' in l:
+                    calling_mayavi = True
+                    break
+        if calling_mayavi:
+            message = _("Changing backend to Qt for Mayavi")
+            self.shellwidget._append_plain_text(message + '\n')
+            self.shellwidget.execute("%gui inline\n%gui qt")
 
     #------ Private API -------------------------------------------------------
     def _create_loading_page(self):
@@ -626,21 +428,6 @@ class ClientWidget(QWidget, SaveHistoryMixin):
         self.infowidget.hide()
         self.shellwidget.show()
         self.infowidget.setHtml(BLANK)
-        self.shellwidget.sig_prompt_ready.disconnect(self._hide_loading_page)
 
-    def _read_stderr(self):
-        """Read the stderr file of the kernel."""
-        stderr_text = open(self.stderr_file, 'rb').read()
-        encoding = get_coding(stderr_text)
-        stderr = to_text_string(stderr_text, encoding)
-        return stderr
-
-    def _show_mpl_backend_errors(self):
-        """
-        Show possible errors when setting the selected Matplotlib backend.
-        """
-        if not self.external_kernel:
-            self.shellwidget.silent_execute(
-                    "get_ipython().kernel._show_mpl_backend_errors()")
-        self.shellwidget.sig_prompt_ready.disconnect(
-            self._show_mpl_backend_errors)
+        document = self.get_control().document()
+        document.contentsChange.disconnect(self._hide_loading_page)
